@@ -65,6 +65,7 @@ ask_and_load_lang_set
 prepare_ocsroot="no"
 pause_in_the_end="yes"
 prompt_drbl_live="yes"
+autologin_group="autologin"
 #
 while [ $# -gt 0 ]; do
   case "$1" in
@@ -137,6 +138,21 @@ case "$switch" in
      rm -f /etc/rcS.d/*kbd-conf
      rm -f /etc/rcS.d/*Forcevideo-drbl-live 
 
+     # Before running drblpush, first we add a group for the autologin accounts
+     if [ -z "$(grep -E "^$autologin_group:" /etc/group)" ]; then
+       groupadd "$autologin_group"
+     fi
+
+     # Now we can add the group "$autologin_group" to sudo
+     if [ -e /etc/sudoers -a -x /usr/sbin/xfsm-shutdown-helper ]; then
+       if [ -z "$(grep -E "^%$autologin_group ALL=NOPASSWD:.*xfsm-shutdown-helper" /etc/sudoers)" ]; then
+         chmod u+w /etc/sudoers
+         echo "# Added by DRBL" >> /etc/sudoers
+         echo "%$autologin_group ALL=NOPASSWD:/usr/sbin/xfsm-shutdown-helper" >> /etc/sudoers
+         chmod u-w /etc/sudoers
+       fi
+     fi
+
      # load $client_no_per_NIC and $autologin_passwd_opt for later use
      . $drbl_setup_path/files/ocs/live-hook/ocs-live-hook.conf
 
@@ -167,6 +183,15 @@ case "$switch" in
      esac
      drbl-login-switch -a --no_nis_update -p "${passwd_autologin}"
 
+     # Add the auto login accounts in every client so that we can add them to the group "autologin"
+     echo -n "Adding the auto login accounts to the group $autologin_group..."
+     for ihost in `get-client-ip-list`; do
+       iaccount="$(get_existing_autologin_account $ihost)"
+       adduser $iaccount $autologin_group &>/dev/null
+       echo -n "."
+     done
+     echo " done!"
+
      echo "$msg_delimiter_star_line"
      # turn on tcpwrapper
      echo "Setting /etc/hosts.allow..."
